@@ -31,6 +31,32 @@ namespace Glest{ namespace Game{
 ///	The AI will interact with the game through this interface
 // =====================================================
 
+class AiInterfaceThread : public BaseThread, public SlaveThreadControllerInterface {
+protected:
+
+	AiInterface *aiIntf;
+	Semaphore semTaskSignalled;
+	Mutex *triggerIdMutex;
+	std::pair<int,bool> frameIndex;
+	MasterSlaveThreadController *masterController;
+
+	virtual void setQuitStatus(bool value);
+	virtual void setTaskCompleted(int frameIndex);
+
+public:
+	AiInterfaceThread(AiInterface *aiIntf);
+	virtual ~AiInterfaceThread();
+    virtual void execute();
+    void signal(int frameIndex);
+    bool isSignalCompleted(int frameIndex);
+
+	virtual void setMasterController(MasterSlaveThreadController *master) { masterController = master; }
+	virtual void signalSlave(void *userdata) { signal(*((int *)(userdata))); }
+
+	virtual void signalQuit();
+	virtual bool canShutdown(bool deleteSelfIfShutdownDelayed=false);
+};
+
 class AiInterface {
 private:
     World *world;
@@ -52,13 +78,38 @@ private:
 
     std::map<const ResourceType *,int> cacheUnitHarvestResourceLookup;
 
+    Mutex *aiMutex;
+
+    AiInterfaceThread *workerThread;
+    std::vector<Vec2i> enemyWarningPositionList;
+
 public:
     AiInterface(Game &game, int factionIndex, int teamIndex, int useStartLocation=-1);
     ~AiInterface();
 
+    AiInterface(const AiInterface& obj) {
+    	init();
+		throw megaglest_runtime_error("class AiInterface is NOT safe to copy!");
+	}
+    AiInterface & operator=(const AiInterface& obj) {
+    	init();
+		throw megaglest_runtime_error("class AiInterface is NOT safe to assign!");
+	}
+
 	//main
     void update();
 
+    std::vector<Vec2i> getEnemyWarningPositionList() const { return enemyWarningPositionList; }
+    void removeEnemyWarningPositionFromList(Vec2i &checkPos);
+
+    inline Mutex * getMutex() {return aiMutex;}
+
+    void signalWorkerThread(int frameIndex);
+    bool isWorkerThreadSignalCompleted(int frameIndex);
+    AiInterfaceThread *getWorkerThread() { return workerThread; }
+
+    bool isLogLevelEnabled(int level);
+
 	//get
 	int getTimer() const		{return timer;}
 	int getFactionIndex() const	{return factionIndex;}
@@ -112,6 +163,8 @@ public:
 private:
 	string getLogFilename() const	{return "ai"+intToStr(factionIndex)+".log";}
 	bool executeCommandOverNetwork();
+
+	void init();
 };
 
 }}//end namespace
