@@ -30,22 +30,20 @@ namespace Glest { namespace Game {
 const char *mailString				= " http://bugs.megaglest.org";
 
 // !! Use minor versions !!  Only major and minor version control compatibility!
-// typical version numbers look like this: v3.11-beta1.0   v3.12-dev   v3.12.0
-// don't forget to update source/version.txt
-const string glestVersionString 	= "v3.12.0";
-const string lastCompatibleSaveGameVersionString 	= "v3.9.0";
+// typical version numbers look like this: v3.13-beta1.0   v3.12-dev   v3.12.1
+// don't forget to update file: source/version.txt
+const string glestVersionString 	= "v3.13.0";
+const string lastCompatibleSaveGameVersionString 	= "v3.11.1";
 
-#if defined(GITVERSION)
-    const string GIT_RawRev			= string(GITVERSION);
-    const string GIT_Rev 			= string("Rev: ") + string(GITVERSION);
-#elif defined(GITVERSIONHEADER)
-#include "gitversion.h"
-    const string GIT_RawRev			= string(GITVERSION);
-    const string GIT_Rev 			= string("Rev: ") + string(GITVERSION);
-#else
-const string GIT_RawRev			= "$5419.034576d$";
-const string GIT_Rev 			= "$Rev$";
+#if defined(GITVERSIONHEADER)
+	#include "gitversion.h"
 #endif
+#if defined(GITVERSION) || defined(GITVERSIONHEADER)
+	const string GIT_RawRev		= string(GITVERSION);
+#else
+	const string GIT_RawRev		= "$5604.3a5d459$";
+#endif
+const string GIT_Rev 			= string("Rev: ") + string(GIT_RawRev);
 
 string getRAWGITRevisionString() {
 	return GIT_RawRev;
@@ -73,7 +71,7 @@ string getPlatformTypeNameString() {
 	platform = "OpenBSD";
 
 #elif defined(__APPLE__)
-	platform = "MacOSX";
+	platform = "MacOS";
 #elif defined(_AIX)
 	platform = "AIX";
 #elif defined(__ANDROID__)
@@ -214,7 +212,7 @@ string getAboutString1(int i) {
 	case 0: return "MegaGlest " + glestVersionString + " (" + "Shared Library " + sharedLibVersionString + ")";
 	case 1: return GIT_Rev;
 	case 2: return "Copyright 2001-2010 The Glest Team";
-	case 3: return "Copyright 2010-2016 The MegaGlest Team";
+	case 3: return "Copyright 2010-2017 The MegaGlest Team";
 	}
 	return "";
 }
