@@ -60,8 +60,8 @@ private:
 	string statusText;
 	bool cancelSelected;
 	GraphicButton buttonCancel;
-
-	//bool masterserverMode;
+	Vec4f displayColor;
+	GraphicButton buttonNextHint;
 
 private:
 	Logger();
@@ -93,6 +93,9 @@ public:
 
 	void clear();
 
+private:
+	void showNextHint();
+
 };
 
 }}//end namespace
