@@ -45,37 +45,7 @@ class SwitchTeamVote;
 //
 ///	Gives commands to the units
 // =====================================================
-
-//
-// This interface describes the methods a callback object must implement
-//
-class CommanderNetworkCallbackInterface {
-public:
-	virtual void commanderNetworkUpdateTask(int id) = 0;
-	virtual ~CommanderNetworkCallbackInterface() {}
-};
-
-class CommanderNetworkThread : public BaseThread
-{
-protected:
-
-	CommanderNetworkCallbackInterface *commanderInterface;
-	Semaphore semTaskSignalled;
-
-	virtual void setQuitStatus(bool value);
-	virtual void setTaskCompleted(int id);
-	Mutex idMutex;
-	std::pair<int,bool> idStatus;
-
-public:
-	CommanderNetworkThread();
-	CommanderNetworkThread(CommanderNetworkCallbackInterface *commanderInterface);
-    virtual void execute();
-    void signalUpdate(int id);
-    bool isSignalCompleted(int id);
-};
-
-class Commander : public CommanderNetworkCallbackInterface {
+class Commander {
 private:
 	typedef vector<std::pair<CommandResult,string> > CommandResultContainer;
 
@@ -83,14 +53,17 @@ private:
     World *world;
 	Chrono perfTimer;
 
-	//CommanderNetworkThread *networkThread;
-	//Game *game;
 	std::vector<std::pair<int,NetworkCommand> > replayCommandList;
 
+	bool pauseNetworkCommands;
+
 public:
     Commander();
     virtual ~Commander();
 
+    bool getPauseNetworkCommands() const { return this->pauseNetworkCommands; }
+    void setPauseNetworkCommands(bool pause) { this->pauseNetworkCommands = pause; }
+
     void signalNetworkUpdate(Game *game);
     void init(World *world);
 	void updateNetwork(Game *game);
@@ -113,20 +86,18 @@ public:
 	void trySwitchTeam(const Faction* faction, int teamIndex) const;
 	void trySwitchTeamVote(const Faction* faction, SwitchTeamVote *vote) const;
 	void tryDisconnectNetworkPlayer(const Faction* faction, int playerIndex) const;
-	void tryPauseGame() const;
-	void tryResumeGame() const;
+
+	void tryPauseGame(bool joinNetworkGame, bool clearCaches) const;
+	void tryResumeGame(bool joinNetworkGame, bool clearCaches) const;
+
 	void tryNetworkPlayerDisconnected(int factionIndex) const;
 
 	Command* buildCommand(const NetworkCommand* networkCommand) const;
 
 private:
 	std::pair<CommandResult,string> pushNetworkCommand(const NetworkCommand* networkCommand) const;
-	//void giveNetworkCommandSpecial(const NetworkCommand* networkCommand) const;
-
 	std::pair<CommandResult,string> computeResult(const CommandResultContainer &results) const;
 	void giveNetworkCommand(NetworkCommand* networkCommand) const;
-
-	virtual void commanderNetworkUpdateTask(int id);
 	bool canSubmitCommandType(const Unit *unit, const CommandType *commandType) const;
 };
 
