@@ -25,6 +25,7 @@
 #include "renderer.h"
 #include <algorithm>
 #include "config.h"
+#include "window.h"
 #include "leak_dumper.h"
 
 using namespace std;
@@ -40,8 +41,10 @@ const char *DEFAULT_LANGUAGE = "english";
 // =====================================================
 
 Lang::Lang() {
-	language 			= "";
-	is_utf8_language 	= false;
+	language 					= "";
+	is_utf8_language 			= false;
+	allowNativeLanguageTechtree = true;
+	techNameLoaded				= "";
 }
 
 Lang &Lang::getInstance() {
@@ -53,128 +56,133 @@ string Lang::getDefaultLanguage() const {
 	return DEFAULT_LANGUAGE;
 }
 
-void Lang::loadStrings(string uselanguage, bool loadFonts,
+void Lang::loadGameStrings(string uselanguage, bool loadFonts,
 		bool fallbackToDefault) {
 	if(uselanguage.length() == 2 || (uselanguage.length() == 5 && uselanguage[2] == '-')) {
 		uselanguage = getLanguageFile(uselanguage);
 	}
 	bool languageChanged = (uselanguage != this->language);
 	this->language= uselanguage;
-	loadStrings(uselanguage, strings, true, fallbackToDefault);
+	loadGameStringProperties(uselanguage, gameStringsAllLanguages[this->language], true, fallbackToDefault);
 
 	if(languageChanged == true) {
 		Font::resetToDefaults();
 		Lang &lang = Lang::getInstance();
 		if(	lang.hasString("FONT_BASE_SIZE")) {
-			Font::baseSize    = strToInt(lang.get("FONT_BASE_SIZE"));
+			Font::baseSize    = strToInt(lang.getString("FONT_BASE_SIZE"));
 		}
 
 		if(	lang.hasString("FONT_SCALE_SIZE")) {
-			Font::scaleFontValue = strToFloat(lang.get("FONT_SCALE_SIZE"));
+			Font::scaleFontValue = strToFloat(lang.getString("FONT_SCALE_SIZE"));
 		}
 		if(	lang.hasString("FONT_SCALE_CENTERH_FACTOR")) {
-			Font::scaleFontValueCenterHFactor = strToFloat(lang.get("FONT_SCALE_CENTERH_FACTOR"));
+			Font::scaleFontValueCenterHFactor = strToFloat(lang.getString("FONT_SCALE_CENTERH_FACTOR"));
 		}
 
 		if(	lang.hasString("FONT_CHARCOUNT")) {
 			// 256 for English
 			// 30000 for Chinese
-			Font::charCount    = strToInt(lang.get("FONT_CHARCOUNT"));
+			Font::charCount    = strToInt(lang.getString("FONT_CHARCOUNT"));
 		}
 		if(	lang.hasString("FONT_TYPENAME")) {
-			Font::fontTypeName = lang.get("FONT_TYPENAME");
+			Font::fontTypeName = lang.getString("FONT_TYPENAME");
 		}
 		if(	lang.hasString("FONT_CHARSET")) {
 			// Example values:
 			// DEFAULT_CHARSET (English) = 1
 			// GB2312_CHARSET (Chinese)  = 134
-			Shared::Platform::charSet = strToInt(lang.get("FONT_CHARSET"));
+			Shared::Platform::PlatformContextGl::charSet = strToInt(lang.getString("FONT_CHARSET"));
 		}
 		if(	lang.hasString("FONT_MULTIBYTE")) {
-			Font::fontIsMultibyte 	= strToBool(lang.get("FONT_MULTIBYTE"));
+			Font::fontIsMultibyte 	= strToBool(lang.getString("FONT_MULTIBYTE"));
 		}
 
 		if(	lang.hasString("FONT_RIGHTTOLEFT")) {
-			Font::fontIsRightToLeft	= strToBool(lang.get("FONT_RIGHTTOLEFT"));
+			Font::fontIsRightToLeft	= strToBool(lang.getString("FONT_RIGHTTOLEFT"));
+		}
+
+		if(	lang.hasString("FONT_RIGHTTOLEFT_MIXED_SUPPORT")) {
+			Font::fontSupportMixedRightToLeft = strToBool(lang.getString("FONT_RIGHTTOLEFT_MIXED_SUPPORT"));
 		}
 
 		if(	lang.hasString("MEGAGLEST_FONT")) {
 			//setenv("MEGAGLEST_FONT","/usr/share/fonts/truetype/ttf-japanese-gothic.ttf",0); // Japanese
 	#if defined(WIN32)
-			string newEnvValue = "MEGAGLEST_FONT=" + lang.get("MEGAGLEST_FONT");
+			string newEnvValue = "MEGAGLEST_FONT=" + lang.getString("MEGAGLEST_FONT");
 			_putenv(newEnvValue.c_str());
 	#else
-			setenv("MEGAGLEST_FONT",lang.get("MEGAGLEST_FONT").c_str(),0);
+			setenv("MEGAGLEST_FONT",lang.getString("MEGAGLEST_FONT").c_str(),0);
 	#endif
 		}
 
 		if(	lang.hasString("MEGAGLEST_FONT_FAMILY")) {
 	#if defined(WIN32)
-			string newEnvValue = "MEGAGLEST_FONT_FAMILY=" + lang.get("MEGAGLEST_FONT_FAMILY");
+			string newEnvValue = "MEGAGLEST_FONT_FAMILY=" + lang.getString("MEGAGLEST_FONT_FAMILY");
 			_putenv(newEnvValue.c_str());
 	#else
-			setenv("MEGAGLEST_FONT_FAMILY",lang.get("MEGAGLEST_FONT_FAMILY").c_str(),0);
+			setenv("MEGAGLEST_FONT_FAMILY",lang.getString("MEGAGLEST_FONT_FAMILY").c_str(),0);
 	#endif
 		}
 
-	//        if(	lang.hasString("FONT_YOFFSET_FACTOR")) {
-	//        	FontMetrics::DEFAULT_Y_OFFSET_FACTOR = strToFloat(lang.get("FONT_YOFFSET_FACTOR"));
-	//		}
-
 	#if defined(WIN32)
 		// Win32 overrides for fonts (just in case they must be different)
 
 		if(	lang.hasString("FONT_BASE_SIZE_WINDOWS")) {
 			// 256 for English
 			// 30000 for Chinese
-			Font::baseSize    = strToInt(lang.get("FONT_BASE_SIZE_WINDOWS"));
+			Font::baseSize    = strToInt(lang.getString("FONT_BASE_SIZE_WINDOWS"));
 		}
 
 		if(	lang.hasString("FONT_SCALE_SIZE_WINDOWS")) {
-			Font::scaleFontValue = strToFloat(lang.get("FONT_SCALE_SIZE_WINDOWS"));
+			Font::scaleFontValue = strToFloat(lang.getString("FONT_SCALE_SIZE_WINDOWS"));
 		}
 		if(	lang.hasString("FONT_SCALE_CENTERH_FACTOR_WINDOWS")) {
-			Font::scaleFontValueCenterHFactor = strToFloat(lang.get("FONT_SCALE_CENTERH_FACTOR_WINDOWS"));
+			Font::scaleFontValueCenterHFactor = strToFloat(lang.getString("FONT_SCALE_CENTERH_FACTOR_WINDOWS"));
 		}
 
 		if(	lang.hasString("FONT_HEIGHT_TEXT_WINDOWS")) {
-			Font::langHeightText = lang.get("FONT_HEIGHT_TEXT_WINDOWS",Font::langHeightText.c_str());
+			Font::langHeightText = lang.getString("FONT_HEIGHT_TEXT_WINDOWS",Font::langHeightText.c_str());
 		}
 
 		if(	lang.hasString("FONT_CHARCOUNT_WINDOWS")) {
 			// 256 for English
 			// 30000 for Chinese
-			Font::charCount    = strToInt(lang.get("FONT_CHARCOUNT_WINDOWS"));
+			Font::charCount    = strToInt(lang.getString("FONT_CHARCOUNT_WINDOWS"));
 		}
 		if(	lang.hasString("FONT_TYPENAME_WINDOWS")) {
-			Font::fontTypeName = lang.get("FONT_TYPENAME_WINDOWS");
+			Font::fontTypeName = lang.getString("FONT_TYPENAME_WINDOWS");
 		}
 		if(	lang.hasString("FONT_CHARSET_WINDOWS")) {
 			// Example values:
 			// DEFAULT_CHARSET (English) = 1
 			// GB2312_CHARSET (Chinese)  = 134
-			Shared::Platform::charSet = strToInt(lang.get("FONT_CHARSET_WINDOWS"));
+			Shared::Platform::PlatformContextGl::charSet = strToInt(lang.getString("FONT_CHARSET_WINDOWS"));
 		}
 		if(	lang.hasString("FONT_MULTIBYTE_WINDOWS")) {
-			Font::fontIsMultibyte 	= strToBool(lang.get("FONT_MULTIBYTE_WINDOWS"));
+			Font::fontIsMultibyte 	= strToBool(lang.getString("FONT_MULTIBYTE_WINDOWS"));
 		}
 		if(	lang.hasString("FONT_RIGHTTOLEFT_WINDOWS")) {
-			Font::fontIsRightToLeft	= strToBool(lang.get("FONT_RIGHTTOLEFT_WINDOWS"));
+			Font::fontIsRightToLeft	= strToBool(lang.getString("FONT_RIGHTTOLEFT_WINDOWS"));
 		}
 
 		if(	lang.hasString("MEGAGLEST_FONT_WINDOWS")) {
 			//setenv("MEGAGLEST_FONT","/usr/share/fonts/truetype/ttf-japanese-gothic.ttf",0); // Japanese
-			string newEnvValue = "MEGAGLEST_FONT=" + lang.get("MEGAGLEST_FONT_WINDOWS");
+			string newEnvValue = "MEGAGLEST_FONT=" + lang.getString("MEGAGLEST_FONT_WINDOWS");
 			_putenv(newEnvValue.c_str());
 		}
 
-	//        if(	lang.hasString("FONT_YOFFSET_FACTOR_WINDOWS")) {
-	//        	FontMetrics::DEFAULT_Y_OFFSET_FACTOR = strToFloat(lang.get("FONT_YOFFSET_FACTOR_WINDOWS"));
-	//		}
-
 		// end win32
 	#endif
 
+
+		if(	lang.hasString("ALLOWED_SPECIAL_KEYS","",false)) {
+			string allowedKeys = lang.getString("ALLOWED_SPECIAL_KEYS");
+			Window::addAllowedKeys(allowedKeys);
+		}
+		else {
+			Window::clearAllowedKeys();
+		}
+
 		if(loadFonts == true) {
 			CoreData &coreData= CoreData::getInstance();
 			coreData.loadFonts();
@@ -182,7 +190,7 @@ void Lang::loadStrings(string uselanguage, bool loadFonts,
     }
 }
 
-void Lang::loadStrings(string uselanguage, Properties &properties, bool fileMustExist,
+void Lang::loadGameStringProperties(string uselanguage, Properties &properties, bool fileMustExist,
 		bool fallbackToDefault) {
 	properties.clear();
 	string data_path = getGameReadWritePath(GameConstants::path_data_CacheLookupKey);
@@ -206,12 +214,20 @@ bool Lang::isUTF8Language() const {
 	return is_utf8_language;
 }
 
-void Lang::loadScenarioStrings(string scenarioDir, string scenarioName){
+void Lang::loadScenarioStrings(string scenarioDir, string scenarioName, bool isTutorial) {
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] scenarioDir = [%s] scenarioName = [%s]\n",__FILE__,__FUNCTION__,__LINE__,scenarioDir.c_str(),scenarioName.c_str());
 
+	//printf("Loading scenario scenarioDir [%s] scenarioName [%s]\n",scenarioDir.c_str(),scenarioName.c_str());
+
 	// First try to find scenario lng file in userdata
 	Config &config = Config::getInstance();
-    vector<string> scenarioPaths = config.getPathListForType(ptScenarios);
+    vector<string> scenarioPaths;
+    if(isTutorial == false) {
+    	scenarioPaths = config.getPathListForType(ptScenarios);
+    }
+    else {
+    	scenarioPaths = config.getPathListForType(ptTutorials);
+    }
     if(scenarioPaths.size() > 1) {
         string &scenarioPath = scenarioPaths[1];
 		endPathWithSlash(scenarioPath);
@@ -242,6 +258,8 @@ void Lang::loadScenarioStrings(string scenarioDir, string scenarioName){
 
 	//try to load the current language first
 	if(fileExists(path)) {
+		//printf("#2 Loading scenario path [%s]\n",path.c_str());
+
 		scenarioStrings.load(path);
 	}
 	else{
@@ -252,23 +270,31 @@ void Lang::loadScenarioStrings(string scenarioDir, string scenarioName){
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] path = [%s]\n",__FILE__,__FUNCTION__,__LINE__,path.c_str());
 
 		if(fileExists(path)){
+			//printf("#3 Loading scenario path [%s]\n",path.c_str());
+
 			scenarioStrings.load(path);
 		}
 	}
 }
 
-void Lang::loadTechTreeStrings(string techTree) {
+bool Lang::loadTechTreeStrings(string techTree,bool forceLoad) {
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] techTree = [%s]\n",__FILE__,__FUNCTION__,__LINE__,techTree.c_str());
 
+	//printf("Line: %d techTree = %s forceLoad = %d\n",__LINE__,techTree.c_str(),forceLoad);
+
+	if(forceLoad == false && techTree == techNameLoaded) {
+		return true;
+	}
+
+	bool foundTranslation = false;
+
 	string currentPath = "";
 	Config &config = Config::getInstance();
     vector<string> techPaths = config.getPathListForType(ptTechs);
-    for(int idx = 0; idx < techPaths.size(); idx++) {
+    for(int idx = 0; idx < (int)techPaths.size(); idx++) {
         string &techPath = techPaths[idx];
 		endPathWithSlash(techPath);
 
-        //printf("techPath [%s]\n",techPath.c_str());
-
 		if(folderExists(techPath + techTree) == true) {
 			currentPath = techPath;
 			endPathWithSlash(currentPath);
@@ -281,28 +307,73 @@ void Lang::loadTechTreeStrings(string techTree) {
 	string pathDefault = techTreeFolder + "lang/" + techTree + "_default.lng";
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] path = [%s] pathDefault = [%s]\n",__FILE__,__FUNCTION__,__LINE__,path.c_str(),pathDefault.c_str());
 
-	techTreeStrings.clear();
-	techTreeStringsDefault.clear();
+	//techTreeStrings.clear();
+	//techTreeStringsDefault.clear();
+
+	//printf("Line: %d techTree = %s this->language = %s forceLoad = %d path = %s\n",__LINE__,techTree.c_str(),this->language.c_str(),forceLoad,path.c_str());
 
 	//try to load the current language first
 	if(fileExists(path)) {
-		techTreeStrings.load(path);
+		foundTranslation = true;
+		if(forceLoad == true ||
+			path != techTreeStringsAllLanguages[techTree][this->language].getpath()) {
+
+			//printf("Line: %d techTree = %s forceLoad = %d path = %s\n",__LINE__,techTree.c_str(),forceLoad,path.c_str());
+
+			techTreeStringsAllLanguages[techTree][this->language].load(path);
+			techNameLoaded = techTree;
+		}
+		else if(path == techTreeStringsAllLanguages[techTree][this->language].getpath() &&
+				techTree != techNameLoaded) {
+			techNameLoaded = techTree;
+		}
 	}
 	else {
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] path not found [%s]\n",__FILE__,__FUNCTION__,__LINE__,path.c_str());
 
 		//try english otherwise
-		path = techTreeFolder + "lang/" + techTree + "_english.lng";
+		string default_language = "english";
+		path = techTreeFolder + "lang/" + techTree + "_" + default_language + ".lng";
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] path = [%s]\n",__FILE__,__FUNCTION__,__LINE__,path.c_str());
 
+		//printf("Line: %d techTree = %s forceLoad = %d path = %s\n",__LINE__,techTree.c_str(),forceLoad,path.c_str());
+
 		if(fileExists(path)) {
-			techTreeStrings.load(path);
+			foundTranslation = true;
+			if(forceLoad == true ||
+				path != techTreeStringsAllLanguages[techTree][default_language].getpath()) {
+				//printf("Line: %d techTree = %s forceLoad = %d path = %s\n",__LINE__,techTree.c_str(),forceLoad,path.c_str());
+
+				techTreeStringsAllLanguages[techTree][default_language].load(path);
+				techNameLoaded = techTree;
+			}
+			else if(path == techTreeStringsAllLanguages[techTree][default_language].getpath() &&
+					techTree != techNameLoaded) {
+				techNameLoaded = techTree;
+			}
 		}
 	}
 
 	if(fileExists(pathDefault)) {
-		techTreeStringsDefault.load(pathDefault);
+		foundTranslation = true;
+		string default_language = "default";
+
+		//printf("Line: %d techTree = %s forceLoad = %d default_language = %s\n",__LINE__,techTree.c_str(),forceLoad,default_language.c_str());
+
+		if(forceLoad == true ||
+			pathDefault != techTreeStringsAllLanguages[techTree][default_language].getpath()) {
+			//printf("Line: %d techTree = %s forceLoad = %d pathDefault = %s\n",__LINE__,techTree.c_str(),forceLoad,pathDefault.c_str());
+
+			techTreeStringsAllLanguages[techTree][default_language].load(pathDefault);
+			techNameLoaded = techTree;
+		}
+		else if(pathDefault == techTreeStringsAllLanguages[techTree][default_language].getpath() &&
+				techTree != techNameLoaded) {
+			techNameLoaded = techTree;
+		}
 	}
+
+	return foundTranslation;
 }
 
 void Lang::loadTilesetStrings(string tileset) {
@@ -311,7 +382,7 @@ void Lang::loadTilesetStrings(string tileset) {
 	string currentPath = "";
 	Config &config = Config::getInstance();
     vector<string> tilesetPaths = config.getPathListForType(ptTilesets);
-    for(int idx = 0; idx < tilesetPaths.size(); idx++) {
+    for(int idx = 0; idx < (int)tilesetPaths.size(); idx++) {
         string &tilesetPath = tilesetPaths[idx];
 		endPathWithSlash(tilesetPath);
 
@@ -358,23 +429,23 @@ bool Lang::hasString(const string &s, string uselanguage, bool fallbackToDefault
 	try {
 		if(uselanguage != "") {
 			//printf("#a fallbackToDefault = %d [%s] uselanguage [%s] DEFAULT_LANGUAGE  [%s] this->language [%s]\n",fallbackToDefault,s.c_str(),uselanguage.c_str(),DEFAULT_LANGUAGE,this->language.c_str());
-			if(otherLanguageStrings.find(uselanguage) == otherLanguageStrings.end()) {
-				loadStrings(uselanguage, otherLanguageStrings[uselanguage], false);
+			if(gameStringsAllLanguages.find(uselanguage) == gameStringsAllLanguages.end()) {
+				loadGameStringProperties(uselanguage, gameStringsAllLanguages[uselanguage], false);
 			}
 			//string result2 = otherLanguageStrings[uselanguage].getString(s);
-			otherLanguageStrings[uselanguage].getString(s);
+			gameStringsAllLanguages[uselanguage].getString(s);
 			//printf("#b result2 [%s]\n",result2.c_str());
 
 			result = true;
 		}
 		else {
 			//string result2 = strings.getString(s);
-			strings.getString(s);
+			gameStringsAllLanguages[this->language].getString(s);
 			result = true;
 		}
 	}
 	catch(exception &ex) {
-		if(strings.getpath() != "") {
+		if(gameStringsAllLanguages[this->language].getpath() != "") {
 			if(SystemFlags::VERBOSE_MODE_ENABLED) SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s] for uselanguage [%s]\n",__FILE__,__FUNCTION__,__LINE__,ex.what(),uselanguage.c_str());
 		}
 
@@ -397,29 +468,29 @@ string Lang::parseResult(const string &key, const string &value) {
 	if(value != "$USE_DEFAULT_LANGUAGE_VALUE") {
 		return value;
 	}
-	string result = Lang::get(key, DEFAULT_LANGUAGE);
+	string result = Lang::getString(key, DEFAULT_LANGUAGE);
 	return result;
 }
-string Lang::get(const string &s, string uselanguage, bool fallbackToDefault) {
+string Lang::getString(const string &s, string uselanguage, bool fallbackToDefault) {
 	try {
 		string result = "";
 
 		if(uselanguage != "") {
-			if(otherLanguageStrings.find(uselanguage) == otherLanguageStrings.end()) {
-				loadStrings(uselanguage, otherLanguageStrings[uselanguage], false);
+			if(gameStringsAllLanguages.find(uselanguage) == gameStringsAllLanguages.end()) {
+				loadGameStringProperties(uselanguage, gameStringsAllLanguages[uselanguage], false);
 			}
-			result = otherLanguageStrings[uselanguage].getString(s);
+			result = gameStringsAllLanguages[uselanguage].getString(s);
 			replaceAll(result, "\\n", "\n");
 		}
 		else {
-			result = strings.getString(s);
+			result = gameStringsAllLanguages[this->language].getString(s);
 			replaceAll(result, "\\n", "\n");
 		}
 
 		return parseResult(s, result);;
 	}
 	catch(exception &ex) {
-		if(strings.getpath() != "") {
+		if(gameStringsAllLanguages[this->language].getpath() != "") {
 			if(fallbackToDefault == false || SystemFlags::VERBOSE_MODE_ENABLED) {
 				if(GlobalStaticFlags::getIsNonGraphicalModeEnabled() == false) {
 					if(SystemFlags::VERBOSE_MODE_ENABLED) SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s] uselanguage [%s] text [%s]\n",__FILE__,__FUNCTION__,__LINE__,ex.what(),uselanguage.c_str(),s.c_str());
@@ -431,10 +502,10 @@ string Lang::get(const string &s, string uselanguage, bool fallbackToDefault) {
 
 		//if(fallbackToDefault == true && uselanguage != DEFAULT_LANGUAGE && this->language != DEFAULT_LANGUAGE) {
 		if( uselanguage != DEFAULT_LANGUAGE && this->language != DEFAULT_LANGUAGE) {
-			return get(s, DEFAULT_LANGUAGE, false);
+			return getString(s, DEFAULT_LANGUAGE, false);
 		}
 
-		return "???" + s + "???";
+		//return "???" + s + "???";
 	}
 	return "???" + s + "???";
 }
@@ -451,23 +522,52 @@ string Lang::getScenarioString(const string &s) {
 		}
 		return "???" + s + "???";
 	}
-	return "???" + s + "???";
+}
+
+bool Lang::hasScenarioString(const string &s) {
+	bool result = false;
+	try {
+		scenarioStrings.getString(s);
+		result = true;
+	}
+	catch(exception &ex) {
+		if(scenarioStrings.getpath() != "") {
+			if(SystemFlags::VERBOSE_MODE_ENABLED) SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",__FILE__,__FUNCTION__,__LINE__,ex.what());
+		}
+	}
+	return result;
 }
 
 string Lang::getTechTreeString(const string &s,const char *defaultValue) {
 	try{
 		string result = "";
+		string default_language = "default";
 
-		if(techTreeStrings.hasString(s) == true || defaultValue == NULL) {
-			if(techTreeStrings.hasString(s) == false && techTreeStringsDefault.hasString(s) == true) {
-				result = techTreeStringsDefault.getString(s);
+		//printf("Line: %d techNameLoaded = %s s = %s this->language = %s\n",__LINE__,techNameLoaded.c_str(),s.c_str(),this->language.c_str());
+
+		if(allowNativeLanguageTechtree == true &&
+			(techTreeStringsAllLanguages[techNameLoaded][this->language].hasString(s) == true ||
+					defaultValue == NULL)) {
+			if(techTreeStringsAllLanguages[techNameLoaded][this->language].hasString(s) == false &&
+					techTreeStringsAllLanguages[techNameLoaded][default_language].hasString(s) == true) {
+
+				//printf("Line: %d techNameLoaded = %s s = %s this->language = %s\n",__LINE__,techNameLoaded.c_str(),s.c_str(),this->language.c_str());
+
+				result = techTreeStringsAllLanguages[techNameLoaded][default_language].getString(s);
 			}
 			else {
-				result = techTreeStrings.getString(s);
+
+				//printf("Line: %d techNameLoaded = %s s = %s this->language = %s\n",__LINE__,techNameLoaded.c_str(),s.c_str(),this->language.c_str());
+
+				result = techTreeStringsAllLanguages[techNameLoaded][this->language].getString(s);
 			}
 		}
-		else if(techTreeStringsDefault.hasString(s) == true) {
-			result = techTreeStringsDefault.getString(s);
+		else if(allowNativeLanguageTechtree == true &&
+				techTreeStringsAllLanguages[techNameLoaded][default_language].hasString(s) == true) {
+
+			//printf("Line: %d techNameLoaded = %s s = %s this->language = %s\n",__LINE__,techNameLoaded.c_str(),s.c_str(),this->language.c_str());
+
+			result = techTreeStringsAllLanguages[techNameLoaded][default_language].getString(s);
 		}
 		else if(defaultValue != NULL) {
 			result = defaultValue;
@@ -476,10 +576,10 @@ string Lang::getTechTreeString(const string &s,const char *defaultValue) {
 		return result;
 	}
 	catch(exception &ex) {
-		if(techTreeStrings.getpath() != "") {
+		if(techTreeStringsAllLanguages[techNameLoaded][this->language].getpath() != "") {
 			SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",__FILE__,__FUNCTION__,__LINE__,ex.what());
 		}
-		return "???" + s + "???";
+		//return "???" + s + "???";
 	}
 	return "???" + s + "???";
 }
@@ -509,7 +609,7 @@ string Lang::getTilesetString(const string &s,const char *defaultValue) {
 		if(tilesetStrings.getpath() != "") {
 			SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",__FILE__,__FUNCTION__,__LINE__,ex.what());
 		}
-		return "???" + s + "???";
+		//return "???" + s + "???";
 	}
 	return "???" + s + "???";
 }
@@ -564,14 +664,27 @@ string Lang::getLanguageFile(string uselanguage) {
 
 string Lang::getNativeLanguageName(string uselanguage, string testLanguageFile) {
 	string result = uselanguage;
-	Properties stringsTest;
-	stringsTest.load(testLanguageFile);
 
-	try {
-		result = stringsTest.getString("NativeLanguageName");
+	static map<string,string> cachedNativeLanguageNames;
+	if(cachedNativeLanguageNames.find(testLanguageFile) != cachedNativeLanguageNames.end()) {
+		result = cachedNativeLanguageNames[testLanguageFile];
 	}
-	//catch(const exception &ex) {
-	catch(...) {
+	else {
+		Properties stringsTest;
+		stringsTest.load(testLanguageFile);
+
+		try {
+			result = stringsTest.getString("NativeLanguageName");
+			cachedNativeLanguageNames[testLanguageFile] = result;
+
+			if(SystemFlags::VERBOSE_MODE_ENABLED) printf("Caching native language name for [%s] = [%s]\n",testLanguageFile.c_str(),result.c_str());
+		}
+		catch(const exception &ex) {
+			if(SystemFlags::VERBOSE_MODE_ENABLED) printf("ERROR Caching native language name for [%s] msg: [%s]\n",testLanguageFile.c_str(),ex.what());
+		}
+		catch(...) {
+			if(SystemFlags::VERBOSE_MODE_ENABLED) printf("ERROR Caching native language name for [%s] msg: [UNKNOWN]\n",testLanguageFile.c_str());
+		}
 	}
 
 	return result;
