@@ -32,21 +32,23 @@ using Shared::Util::Properties;
 
 class Lang {
 private:
-	string language;
-	bool is_utf8_language;
 
-	Properties strings;
+	bool is_utf8_language;
+	string language;
+	std::map<string,Properties> gameStringsAllLanguages;
+
 	Properties scenarioStrings;
-	Properties techTreeStrings;
-	Properties techTreeStringsDefault;
+
 	Properties tilesetStrings;
 	Properties tilesetStringsDefault;
 
-	std::map<string,Properties> otherLanguageStrings;
+	std::map<string, std::map<string, Properties> > techTreeStringsAllLanguages;
+	string techNameLoaded;
+	bool allowNativeLanguageTechtree;
 
 private:
 	Lang();
-	void loadStrings(string language, Properties &properties, bool fileMustExist,bool fallbackToDefault=false);
+	void loadGameStringProperties(string language, Properties &properties, bool fileMustExist,bool fallbackToDefault=false);
 	bool fileMatchesISO630Code(string uselanguage, string testLanguageFile);
 	string getNativeLanguageName(string uselanguage, string testLanguageFile);
 
@@ -55,14 +57,21 @@ private:
 public:
 	static Lang &getInstance();    
 
-	void loadStrings(string uselanguage, bool loadFonts=true, bool fallbackToDefault=false);
-	void loadScenarioStrings(string scenarioDir, string scenarioName);
-	void loadTechTreeStrings(string techTree);
+	string getTechNameLoaded() const { return techNameLoaded; }
+	bool getAllowNativeLanguageTechtree() const { return allowNativeLanguageTechtree; }
+	void setAllowNativeLanguageTechtree(bool value) { allowNativeLanguageTechtree = value; }
+
+	void loadGameStrings(string uselanguage, bool loadFonts=true, bool fallbackToDefault=false);
+	void loadScenarioStrings(string scenarioDir, string scenarioName, bool isTutorial);
+	bool loadTechTreeStrings(string techTree, bool forceLoad=false);
 	void loadTilesetStrings(string tileset);
 
-	string get(const string &s,string uselanguage="", bool fallbackToDefault=false);
+	string getString(const string &s,string uselanguage="", bool fallbackToDefault=false);
 	bool hasString(const string &s, string uselanguage="", bool fallbackToDefault=false);
+
 	string getScenarioString(const string &s);
+	bool hasScenarioString(const string &s);
+
 	string getTechTreeString(const string &s, const char *defaultValue=NULL);
 	string getTilesetString(const string &s, const char *defaultValue=NULL);
 
