@@ -24,13 +24,32 @@ namespace Glest{ namespace Game{
 // =====================================================
 
 Metrics::Metrics() {
+	reloadData();
+}
+
+void Metrics::reload(int resWidth, int resHeight) {
+	Metrics *metrics = getInstancePtr();
+	metrics->reloadData(resWidth, resHeight);
+}
+
+void Metrics::reloadData(int resWidth, int resHeight) {
 	Config &config = Config::getInstance();
 	
 	virtualW= 1000;
 	virtualH= 750;
 
-	screenW= config.getInt("ScreenWidth");
-	screenH= config.getInt("ScreenHeight");
+	if(resWidth > 0) {
+		screenW= resWidth;
+	}
+	else {
+		screenW= config.getInt("ScreenWidth");
+	}
+	if(resHeight > 0) {
+		screenH= resHeight;
+	}
+	else {
+		screenH= config.getInt("ScreenHeight");
+	}
 	
 	minimapX= 10;
 	minimapY= 750-128-30+16;
@@ -43,9 +62,14 @@ Metrics::Metrics() {
 	displayH= 480;	
 }
 
+Metrics * Metrics::getInstancePtr() {
+	static Metrics metrics;
+	return &metrics;
+}
+
 const Metrics &Metrics::getInstance(){
-	static const Metrics metrics;
-	return metrics;
+	Metrics *metrics = getInstancePtr();
+	return *metrics;
 }
 
 float Metrics::getAspectRatio() const{
