@@ -43,6 +43,8 @@ private:
 
 private:
 	Metrics();
+	static Metrics *getInstancePtr();
+	void reloadData(int resWidth=-1, int resHeight=-1);
 
 public:
 	static const Metrics &getInstance();
@@ -66,6 +68,8 @@ public:
 
 	bool isInDisplay(int x, int y) const;
 	bool isInMinimap(int x, int y) const;
+
+	static void reload(int resWidth=-1, int resHeight=-1);
 };
 
 }}//end namespace
