@@ -39,15 +39,14 @@ private:
 	Stats stats;
 
 	GraphicButton buttonExit;
-	int mouseX;
-	int mouseY;
 	int mouse2d;
 	GraphicMessageBox mainMessageBox;
 	Texture2D *renderToTexture;
+	uint64 renderToTextureCount;
 	ProgramState *originState;
 	const char *containerName;
 
-	Shared::Graphics::VideoPlayer *menuBackgroundVideo;
+	::Shared::Graphics::VideoPlayer *menuBackgroundVideo;
 	GameSettings *gameSettings;
 	StrSound battleEndMusic;
 
@@ -66,7 +65,6 @@ public:
 	virtual void reloadUI();
 
 private:
-	const string getTimeString(int frames);
 
 	void initBackgroundVideo();
 	std::pair<string,string> getBattleEndVideo(bool won);
