@@ -276,6 +276,11 @@ void MainMenu::setState(MenuState *newstate) {
 		//printf("In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 		//printf("In MainMenu::setState() #5\n");
 	}
+
+	if(this->state != NULL) {
+
+	}
+
 	//printf("In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 	this->state= newstate;
 
@@ -299,12 +304,12 @@ void MainMenu::consoleAddLine(string line) {
 // 	class MenuState
 // =====================================================
 
-MenuState::MenuState(Program *program, MainMenu *mainMenu, const string &stateName){
+MenuState::MenuState(Program *program, MainMenu *mainMenu, const string &stateName) {
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s %d]\n",__FILE__,__FUNCTION__,__LINE__);
-
-	this->containerName="";
+	this->containerName = "MenuState";
 	this->program= program;
 	this->mainMenu= mainMenu;
+	console.registerGraphicComponent(containerName, "menuStateConsole");
 
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s %d]\n",__FILE__,__FUNCTION__,__LINE__);
 	//switch on menu music again, it might be muted
@@ -342,7 +347,7 @@ MenuState::MenuState(Program *program, MainMenu *mainMenu, const string &stateNa
 		degToRad(startRotation.x),
 		degToRad(startRotation.y),
 		degToRad(startRotation.z))));
-
+		
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s %d]\n",__FILE__,__FUNCTION__,__LINE__);
 }
 
@@ -364,7 +369,7 @@ void MenuState::consoleAddLine(string line) {
 }
 
 void MenuState::reloadUI() {
-	console.resetFonts();
+	//console.resetFonts();
 }
 
 void MenuState::setActiveInputLabel(GraphicLabel *newLabel, GraphicLabel **activeInputLabelPtr) {
