@@ -36,15 +36,21 @@ public:
 	static NetworkManager &getInstance();
 
 	NetworkManager();
+	virtual ~NetworkManager();
+
 	void init(NetworkRole networkRole,bool publishEnabled=false);
 	void end();
 	void update();
 
 	bool isNetworkGame();
+	bool isNetworkGameWithConnectedClients();
+
 	GameNetworkInterface* getGameNetworkInterface(bool throwErrorOnNull=true);
 	ServerInterface* getServerInterface(bool throwErrorOnNull=true);
 	ClientInterface* getClientInterface(bool throwErrorOnNull=true);
 	NetworkRole getNetworkRole() const { return networkRole; }
+
+	void initServerInterfaces(ClientLagCallbackInterface *intf);
 };
 
 }}//end namespace
