@@ -49,7 +49,7 @@ public:
 	virtual ~ObjectStateInterface() {}
 };
 
-class Object : public BaseColorPickEntity {
+class Object : public BaseColorPickEntity, public ParticleOwner {
 private:
 	typedef vector<UnitParticleSystem*> UnitParticleSystems;
 
@@ -63,6 +63,7 @@ private:
 	int lastRenderFrame;
 	Vec2i mapPos;
 	bool visible;
+	bool animated;
 	float animProgress;
 	float highlight;
 
@@ -72,7 +73,8 @@ public:
 	Object(ObjectType *objectType, const Vec3f &pos, const Vec2i &mapPos);
 	virtual ~Object();
 
-	void end(); //to kill particles
+	virtual void end(); //to kill particles
+	virtual void logParticleInfo(string info) {};
 	void initParticles();
 	void initParticlesFromTypes(const ModelParticleSystemTypes *particleTypes);
 	static void setStateCallback(ObjectStateInterface *value) { stateCallback=value; }
@@ -86,6 +88,7 @@ public:
 	const Model *getModel() const;
 	Model *getModelPtr() const;
 	bool getWalkable() const;
+	bool isAnimated() const				{return animated;}
 
 	float getHightlight() const			{return highlight;}
 	bool isHighlighted() const			{return highlight>0.f;}
@@ -100,12 +103,15 @@ public:
 
 	const Vec2i & getMapPos() const { return mapPos; }
 
+	void updateHighlight();
 	void update();
 	float getAnimProgress() const { return animProgress;}
 
 	virtual string getUniquePickName() const;
 	void saveGame(XmlNode *rootNode);
 	void loadGame(const XmlNode *rootNode,const TechTree *techTree);
+
+	virtual void end(ParticleSystem *particleSystem);
 };
 
 }}//end namespace
