@@ -57,10 +57,10 @@ void Resource::init(const ResourceType *rt, const Vec2i &pos) {
 	addItemToVault(&this->balance,this->balance);
 }
 
-string Resource::getDescription() const {
+string Resource::getDescription(bool translatedValue) const {
      string str;
 
-     str+= type->getName(true);
+     str+= type->getName(translatedValue);
      str+="\n";
      str+= intToStr(amount);
      str+="/";
@@ -119,7 +119,7 @@ void Resource::saveGame(XmlNode *rootNode) const {
 void Resource::loadGame(const XmlNode *rootNode, int index,const TechTree *techTree) {
 	vector<XmlNode *> resourceNodeList = rootNode->getChildList("Resource");
 
-	if(index < resourceNodeList.size()) {
+	if(index < (int)resourceNodeList.size()) {
 		XmlNode *resourceNode = resourceNodeList[index];
 
 		amount = resourceNode->getAttribute("amount")->getIntValue();
@@ -129,4 +129,27 @@ void Resource::loadGame(const XmlNode *rootNode, int index,const TechTree *techT
 	}
 }
 
+std::string Resource::toString() const {
+	std::string result = "resource name = " + this->getDescription(false) + "\n";
+    result += "amount = " + intToStr(this->amount) + "\n";
+    result += "type = " + this->type->getName(false) + "\n";
+    result += "type resources per patch = " + intToStr(type->getDefResPerPatch()) + "\n";
+    result += "pos = " + this->pos.getString() + "\n";
+    result += "balance = " + intToStr(this->balance) + "\n";
+
+    return result;
+}
+
+Checksum Resource::getCRC() {
+	Checksum crcForResource;
+
+	crcForResource.addInt(amount);
+	crcForResource.addString(type->getName(false));
+	crcForResource.addInt(pos.x);
+	crcForResource.addInt(pos.y);
+	crcForResource.addInt(balance);
+
+	return crcForResource;
+}
+
 }}//end namespace
