@@ -749,6 +749,12 @@ string ProduceCommandType::getDesc(const TotalUpgrade *totalUpgrade, bool transl
         str+="+" + intToStr(totalUpgrade->getProdSpeed(produceSkillType));
 	}
     str+="\n";
+    str+=""+Lang::getInstance().getString("TimeSteps",(translatedValue == true ? "" : "english"))+": "+intToStr(getProducedUnit()->getProductionTime())+"\n";
+    int64 speed=produceSkillType->getSpeed()+totalUpgrade->getProdSpeed(produceSkillType);
+    int64 time=getProducedUnit()->getProductionTime();
+    int64 seconds=time*100/speed;
+    str+=""+Lang::getInstance().getString("Time",(translatedValue == true ? "" : "english"))+": "+intToStr(seconds);
+    str+="\n";
 
     //mpcost
 	if(produceSkillType->getEpCost()!=0){
@@ -814,7 +820,18 @@ string UpgradeCommandType::getDesc(const TotalUpgrade *totalUpgrade, bool transl
 	Lang &lang= Lang::getInstance();
 
     str=getName(translatedValue)+"\n";
-    str+= lang.getString("UpgradeSpeed",(translatedValue == true ? "" : "english"))+": "+ intToStr(upgradeSkillType->getSpeed())+"\n";
+    str+= lang.getString("UpgradeSpeed",(translatedValue == true ? "" : "english"))+": "+ intToStr(upgradeSkillType->getSpeed());
+    if(totalUpgrade->getProdSpeed(upgradeSkillType) != 0) {
+            str+= "+" + intToStr(totalUpgrade->getProdSpeed(upgradeSkillType));
+    }
+    str+="\n";
+    str+=""+Lang::getInstance().getString("TimeSteps",(translatedValue == true ? "" : "english"))+": "+intToStr(getProducedUpgrade()->getProductionTime())+"\n";
+    int64 speed=upgradeSkillType->getSpeed()+totalUpgrade->getProdSpeed(upgradeSkillType);
+    int64 time=getProducedUpgrade()->getProductionTime();
+    int64 seconds=time*100/speed;
+    str+=""+Lang::getInstance().getString("Time",(translatedValue == true ? "" : "english"))+": "+intToStr(seconds);
+    str+="\n";
+
     if(upgradeSkillType->getEpCost()!=0)
         str+= lang.getString("EpCost",(translatedValue == true ? "" : "english"))+": "+intToStr(upgradeSkillType->getEpCost())+"\n";
     if(upgradeSkillType->getHpCost()!=0)
@@ -889,7 +906,17 @@ string MorphCommandType::getDesc(const TotalUpgrade *totalUpgrade, bool translat
 	Lang &lang= Lang::getInstance();
 
     //prod speed
-    str+= lang.getString("MorphSpeed",(translatedValue == true ? "" : "english"))+": "+ intToStr(morphSkillType->getSpeed())+"\n";
+    str+= lang.getString("MorphSpeed",(translatedValue == true ? "" : "english"))+": "+ intToStr(morphSkillType->getSpeed());
+	if(totalUpgrade->getProdSpeed(morphSkillType)!=0){
+        str+="+" + intToStr(totalUpgrade->getProdSpeed(morphSkillType));
+	}
+    str+="\n";
+    str+=""+Lang::getInstance().getString("TimeSteps",(translatedValue == true ? "" : "english"))+": "+intToStr(getMorphUnit()->getProductionTime())+"\n";
+    int64 speed=morphSkillType->getSpeed()+totalUpgrade->getProdSpeed(morphSkillType);
+    int64 time=getMorphUnit()->getProductionTime();
+    int64 seconds=time*100/speed;
+    str+=""+Lang::getInstance().getString("Time",(translatedValue == true ? "" : "english"))+": "+intToStr(seconds);
+    str+="\n";
 
     //mpcost
 	if(morphSkillType->getEpCost()!=0){
