@@ -40,7 +40,7 @@ public:
 		id = -1;
 	}
 	int getId() const					{return id;}
-	const string &getName() const		{return name;}
+	string getName(bool translatedValue=false) const;
 
 	void setName(const string &name)	{this->name= name;}
 	void setId(int id)					{this->id= id;}
@@ -62,7 +62,7 @@ public:
 		id = -1;
 	}
 	int getId() const					{return id;}
-	const string &getName() const		{return name;}
+	string getName(bool translatedValue=false) const;
 
 	void setName(const string &name)	{this->name= name;}
 	void setId(int id)					{this->id= id;}
@@ -79,7 +79,7 @@ public:
 
 class DamageMultiplierTable {
 private:
-	float *values;
+	double *values;
 	int attackTypeCount;
 	int armorTypeCount;
 
@@ -88,8 +88,8 @@ public:
 	~DamageMultiplierTable();
 
 	void init(int attackTypeCount, int armorTypeCount);
-	float getDamageMultiplier(const AttackType *att, const ArmorType *art) const; 
-	void setDamageMultiplier(const AttackType *att, const ArmorType *art, float value);
+	double getDamageMultiplier(const AttackType *att, const ArmorType *art) const;
+	void setDamageMultiplier(const AttackType *att, const ArmorType *art, double value);
 
 	void saveGame(XmlNode *rootNode);
 };
