@@ -246,9 +246,13 @@ void TechTree::load(const string &dir, set<string> &factions, Checksum* checksum
         	resourceTypes[i].deletePixels();
         }
     }
-    catch(const exception &e){
-    	SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,e.what());
-		throw megaglest_runtime_error("Error loading Resource Types in: [" + currentPath + "]\n" + e.what(),isValidationModeEnabled);
+    catch(megaglest_runtime_error& ex) {
+		SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,ex.what());
+		throw megaglest_runtime_error("Error loading Resource Types in: "+ currentPath + "\nMessage: " + ex.what(),!ex.wantStackTrace() || isValidationModeEnabled);
+    }
+	catch(const exception &e){
+		SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,e.what());
+		throw megaglest_runtime_error("Error loading Resource Types in: "+ currentPath + "\nMessage: " + e.what(),isValidationModeEnabled);
     }
 
     // give CPU time to update other things to avoid apperance of hanging
@@ -318,9 +322,13 @@ void TechTree::load(const string &dir, set<string> &factions, Checksum* checksum
 			SDL_PumpEvents();
 		}
     }
-    catch(const exception &e){
-    	SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,e.what());
-		throw megaglest_runtime_error("Error loading Tech Tree: "+ currentPath + "\n" + e.what(),isValidationModeEnabled);
+    catch(megaglest_runtime_error& ex) {
+		SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,ex.what());
+		throw megaglest_runtime_error("Error loading Tech Tree: "+ currentPath + "\nMessage: " + ex.what(),!ex.wantStackTrace() || isValidationModeEnabled);
+    }
+	catch(const exception &e){
+		SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,e.what());
+		throw megaglest_runtime_error("Error loading Tech Tree: "+ currentPath + "\nMessage: " + e.what(),isValidationModeEnabled);
     }
 
     // give CPU time to update other things to avoid apperance of hanging
@@ -446,7 +454,7 @@ FactionType *TechTree::getTypeByName(const string &name) {
           }
     }
     if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__);
-    throw megaglest_runtime_error("Faction not found: " + name,isValidationModeEnabled);
+    throw megaglest_runtime_error("Faction not found: " + name,true);
 }
 
 const FactionType *TechTree::getType(const string &name) const {
@@ -456,7 +464,7 @@ const FactionType *TechTree::getType(const string &name) const {
           }
     }
     if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__);
-    throw megaglest_runtime_error("Faction not found: " + name,isValidationModeEnabled);
+    throw megaglest_runtime_error("Faction not found: " + name,true);
 }
 
 const ResourceType *TechTree::getTechResourceType(int i) const{
@@ -483,7 +491,7 @@ const ResourceType *TechTree::getFirstTechResourceType() const{
 
      char szBuf[8096]="";
      snprintf(szBuf,8096,"The referenced tech tree [%s] is either missing or has no resources defined but at least one resource is required.",this->name.c_str());
-     throw megaglest_runtime_error(szBuf,isValidationModeEnabled);
+     throw megaglest_runtime_error(szBuf,true);
 }
 
 const ResourceType *TechTree::getResourceType(const string &name) const{
@@ -494,7 +502,7 @@ const ResourceType *TechTree::getResourceType(const string &name) const{
 		}
 	}
 
-	throw megaglest_runtime_error("Resource Type not found: " + name,isValidationModeEnabled);
+	throw megaglest_runtime_error("Resource Type not found: " + name,true);
 }
 
 const ArmorType *TechTree::getArmorType(const string &name) const{
@@ -504,7 +512,7 @@ const ArmorType *TechTree::getArmorType(const string &name) const{
 		}
 	}
 
-	throw megaglest_runtime_error("Armor Type not found: " + name,isValidationModeEnabled);
+	throw megaglest_runtime_error("Armor Type not found: " + name,true);
 }
 
 const AttackType *TechTree::getAttackType(const string &name) const{
@@ -514,7 +522,7 @@ const AttackType *TechTree::getAttackType(const string &name) const{
 		}
 	}
 
-	throw megaglest_runtime_error("Attack Type not found: " + name,isValidationModeEnabled);
+	throw megaglest_runtime_error("Attack Type not found: " + name,true);
 }
 
 double TechTree::getDamageMultiplier(const AttackType *att, const ArmorType *art) const {
