@@ -22,6 +22,8 @@ TilesetModelType::TilesetModelType() {
 	model = NULL;
 	height = 0;
 	rotationAllowed = false;
+	smoothTwoFrameAnim = false;
+	randomPositionEnabled = false;
 
 	animSpeed = 0;
 }
