@@ -192,9 +192,11 @@ private:
 	float healthbarthickness;
 	int healthbarVisible;
     bool multiSelect;
+    bool uniformSelect;
     bool commandable;
     int sight;
     int size;							//size in cells
+    int aiBuildSize;
     int renderSize;						//size to render in cells
     int height;
     int burnHeight;
@@ -283,9 +285,11 @@ public:
 	inline float getHealthbarThickness() const							{return healthbarthickness;}
 	inline int getHealthbarVisible() const							{return healthbarVisible;}
 	inline bool getMultiSelect() const							{return multiSelect;}
+	inline bool getUniformSelect() const							{return uniformSelect;}
 	inline bool isCommandable() const							{return commandable;}
 	inline int getSight() const								{return sight;}
 	inline int getSize() const									{return size;}
+	inline int getAiBuildSize() const							{return aiBuildSize;}
 	inline int getRenderSize() const								{return renderSize;}
 	int getHeight() const										{return height;}
 	int getBurnHeight() const								{return burnHeight;}
