@@ -1057,9 +1057,13 @@ void UpgradeType::load(const string &dir, const TechTree *techTree,
 		//values
 		UpgradeTypeBase::load(upgradeNode,name);
 	}
+    catch(megaglest_runtime_error& ex) {
+		SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,ex.what());
+		throw megaglest_runtime_error("Error loading UpgradeType: "+ currentPath + "\nMessage: " + ex.what(),!ex.wantStackTrace() );
+    }
 	catch(const exception &e){
 		SystemFlags::OutputDebug(SystemFlags::debugError,"In [%s::%s Line: %d] Error [%s]\n",__FILE__,__FUNCTION__,__LINE__,e.what());
-		throw megaglest_runtime_error("Error loading UpgradeType: "+ dir + "\n" +e.what());
+		throw megaglest_runtime_error("Error loading UpgradeType: "+ currentPath + "\n" +e.what());
 	}
 
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
