@@ -32,7 +32,11 @@ namespace ImageRegisterer {
 	bool registerImageReaders();
 
 	//Since you can't call void methods here, I have used a method doing nothing except initializing the image Readers
+#ifdef WIN32
 	static bool readersRegistered = registerImageReaders(); //should always return true, this should guarantee that the readers are registered <--> ImageReaders is included anywhere
+#else
+	static bool readersRegistered __attribute__((unused)) = registerImageReaders(); //should always return true, this should guarantee that the readers are registered <--> ImageReaders is included anywhere
+#endif
 }
 
 }} //end namespace
