@@ -35,7 +35,7 @@ enum ResourceScope {
 class RendererInterface {
 public:
 	virtual Texture2D *newTexture2D(ResourceScope rs) = 0;
-	virtual Model *newModel(ResourceScope rs) = 0;
+	virtual Model *newModel(ResourceScope rs,const string &path,bool deletePixMapAfterLoad=false,std::map<string,vector<pair<string, string> > > *loadedFileList=NULL, string *sourceLoader=NULL) = 0;
 
 	virtual ~RendererInterface() {}
 };
@@ -43,7 +43,7 @@ public:
 class RendererMapInterface {
 public:
 	virtual void initMapSurface(int clientW, int clientH) = 0;
-	virtual void renderMap(MapPreview *map, int x, int y, int clientW, int clientH, int cellSize, bool grid) = 0;
+	virtual void renderMap(MapPreview *map, int x, int y, int clientW, int clientH, int cellSize, bool grid, bool heightMap, bool hideWater) = 0;
 
 	virtual ~RendererMapInterface() {}
 };
