@@ -47,6 +47,7 @@ private:
 	string sandboxCode;
 
 	static bool disableSandbox;
+	static bool debugModeEnabled;
 
 	void DumpGlobals();
 
@@ -54,6 +55,9 @@ public:
 	LuaScript();
 	~LuaScript();
 
+	static void setDebugModeEnabled(bool value) { debugModeEnabled = value; }
+	static bool getDebugModeEnabled() { return debugModeEnabled; }
+
 	static void setDisableSandbox(bool value) { disableSandbox = value; }
 
 	void loadCode(string code, string name);
@@ -100,6 +104,7 @@ public:
 	int getReturnCount() const					{return returnCount;}
 
 	void returnInt(int value);
+	void returnFloat(float value);
 	void returnString(const string &value);
 	void returnVec2i(const Vec2i &value);
 	void returnVec4i(const Vec4i &value);
