@@ -29,17 +29,17 @@ namespace Shared { namespace PlatformCommon {
 class BaseThread : public Thread
 {
 protected:
-	Mutex mutexRunning;
-	Mutex mutexQuit;
-	Mutex mutexBeginExecution;
-	Mutex mutexDeleteSelfOnExecutionDone;
+	Mutex *mutexRunning;
+	Mutex *mutexQuit;
+	Mutex *mutexBeginExecution;
+	Mutex *mutexDeleteSelfOnExecutionDone;
 
-    Mutex mutexThreadObjectAccessor;
+    Mutex *mutexThreadObjectAccessor;
 
     bool threadOwnerValid;
-    Mutex mutexThreadOwnerValid;
+    Mutex *mutexThreadOwnerValid;
 
-	Mutex mutexExecutingTask;
+	Mutex *mutexExecutingTask;
 	bool executingTask;
 
 	void *ptr;
@@ -52,11 +52,15 @@ protected:
 	bool hasBeginExecution;
 	bool deleteSelfOnExecutionDone;
 
+	Mutex *mutexStarted;
+	bool started;
+
 	virtual void setQuitStatus(bool value);
 	void deleteSelfIfRequired();
 
 	void *genericData;
 
+
 public:
 	BaseThread();
 	virtual ~BaseThread();
@@ -66,6 +70,9 @@ public:
 	virtual bool getQuitStatus();
 	virtual bool getRunningStatus();
 
+	virtual bool getStarted();
+	virtual void setStarted(bool value);
+
 	virtual bool getHasBeginExecution();
 	virtual void setHasBeginExecution(bool value);
 
@@ -89,12 +96,16 @@ public:
     bool getThreadOwnerValid();
     Mutex * getMutexThreadOwnerValid();
 
-    Mutex * getMutexThreadObjectAccessor() { return &mutexThreadObjectAccessor; }
+    Mutex * getMutexThreadObjectAccessor();
 
-    template <typename T>
-    T * getGenericData() { return genericData; }
-    template <typename T>
-    void setGenericData(T *value) { genericData = value; }
+	template <typename T>
+	T * getGenericData() { 
+		return genericData; 
+	}
+	template <typename T>
+	void setGenericData(T *value) { 
+		genericData = value; 
+	}
 
     static bool isThreadDeleted(void *ptr);
 };
