@@ -51,7 +51,7 @@ public:
 	};
 	virtual bool init(const SoundPlayerParams *params)= 0;
 	virtual void end()= 0;
-	virtual void play(StaticSound *staticSound)= 0;
+	virtual void play(StaticSound *staticSound, bool force=false)= 0;
 	virtual	void play(StrSound *strSound, int64 fadeOn=0)= 0;	//delay and fade in miliseconds
 	virtual void stop(StrSound *strSound, int64 fadeOff=0)= 0;
 	virtual void stopAllSounds(int64 fadeOff=0)= 0;
