@@ -60,7 +60,7 @@ LOCAL uint8_t scratchBuf[LEN_SCRATCHBUF];
 int ftpSendMsg(msgmode_E mode, int sessionId, int ret, const char* msg)
 {
 	int sentlen = 0;
-	int len = strlen(msg);
+	int len = (int)strlen(msg);
 	char buf[6];
 
 	if(mode == MSG_QUOTE)
@@ -86,7 +86,7 @@ if(VERBOSE_MODE_ENABLED) printf("%02d <-- %s%s\n", sessionId, buf, msg);
 int ftpExecTransmission(int sessionId)
 {
 	int finished = FALSE;
-	int len;
+	size_t len;
     ftpSession_S *pSession = ftpGetSession(sessionId);
 	transmission_S *pTrans = &pSession->activeTrans;
 	int rxLen;
@@ -99,8 +99,8 @@ int ftpExecTransmission(int sessionId)
         len = ftpReadFile(scratchBuf, 1, LEN_SCRATCHBUF, pTrans->fsHandle);
 		if(len > 0)
         {
-			pTrans->fileSize -= len;
-            if(ftpSend(pTrans->dataSocket, scratchBuf, len))
+			pTrans->fileSize -= (uint32_t)len;
+            if(ftpSend(pTrans->dataSocket, scratchBuf, (int)len))
 			{
     	    	ftpSendMsg(MSG_NORMAL, sessionId, 426, ftpMsg000);
     	    	finished = TRUE;
@@ -108,7 +108,7 @@ int ftpExecTransmission(int sessionId)
 		}
 		else
 		{
-			if(VERBOSE_MODE_ENABLED) printf("ERROR in ftpExecTransmission ftpReadFile returned = %d for sessionId = %d\n",len,sessionId);
+			if(VERBOSE_MODE_ENABLED) printf("ERROR in ftpExecTransmission ftpReadFile returned = %d for sessionId = %d\n",(int)len,sessionId);
 	    	ftpSendMsg(MSG_NORMAL, sessionId, 451, ftpMsg001);
 	    	finished = TRUE;
 		}
@@ -125,7 +125,7 @@ int ftpExecTransmission(int sessionId)
 		{
         	len = ftpReceive(pTrans->dataSocket, &scratchBuf[rxLen], LEN_SCRATCHBUF - rxLen);
 
-			if(len <= 0) {
+			if(len < 1) {
 				int errorNumber = getLastSocketError();
 				const char *errText = getLastSocketErrorText(&errorNumber);
 				if(VERBOSE_MODE_ENABLED) printf("ftpExecTransmission ERROR ON RECEIVE for socket = %d, data len = %d, error = %d [%s]\n",pTrans->dataSocket,(LEN_SCRATCHBUF - rxLen),errorNumber,errText);
@@ -133,22 +133,22 @@ int ftpExecTransmission(int sessionId)
 				break;
 			}
 
-			rxLen += len;
+			rxLen += (int)len;
 		} while(rxLen < LEN_SCRATCHBUF);
 
 		if(rxLen > 0)
         {
-			int res = ftpWriteFile(scratchBuf, 1, rxLen, pTrans->fsHandle);
-	        if(res != rxLen)
+			size_t res = ftpWriteFile(scratchBuf, 1, rxLen, pTrans->fsHandle);
+	        if(res != (size_t)rxLen)
 			{
-	        	if(VERBOSE_MODE_ENABLED) printf("ERROR in ftpExecTransmission ftpWriteFile returned = %d for sessionId = %d\n",res,sessionId);
+	        	if(VERBOSE_MODE_ENABLED) printf("ERROR in ftpExecTransmission ftpWriteFile returned = %d for sessionId = %d\n",(int)res,sessionId);
 
 		    	ftpSendMsg(MSG_NORMAL, sessionId, 451, ftpMsg001);
     	    	finished = TRUE;
 			}
 		}
 
-		if(len <= 0)
+		if(len < 1)
 		{
 	    	ftpSendMsg(MSG_NORMAL, sessionId, 226, ftpMsg003);
 	    	finished = TRUE;
@@ -201,8 +201,8 @@ LOCAL int ftpCmdSyst(int sessionId, const char* args, int len)
 }
 LOCAL int ftpCmdPort(int sessionId, const char* args, int len)
 {
-	char clientIp[16];
-	uint16_t clientPort;
+	//char clientIp[16]="";
+	uint16_t clientPort=0;
 
 	int commaCnt = 0;
 	int n;
@@ -215,13 +215,13 @@ LOCAL int ftpCmdPort(int sessionId, const char* args, int len)
 			if(args[n] == ',')
 			{
 				commaCnt++;
-				if(commaCnt < 4)
-					clientIp[n] = '.';
-				else
-					clientIp[n] = '\0';
+//				if(commaCnt < 4)
+//					clientIp[n] = '.';
+//				else
+//					clientIp[n] = '\0';
 			}
-			else
-				clientIp[n] = args[n];
+//			else
+//				clientIp[n] = args[n];
 		}
 		else				// Port-Nummer
 		{
@@ -957,7 +957,7 @@ int execFtpCmd(int sessionId, const char* cmd, int cmdlen)
 	//if(VERBOSE_MODE_ENABLED) printf("In execFtpCmd ARRAY_SIZE(cmds) = %lu for sessionId = %d\n",ARRAY_SIZE(cmds),sessionId);
 	if(VERBOSE_MODE_ENABLED) printf("In execFtpCmd cmd [%s] for sessionId = %d\n",cmd,sessionId);
 
-	for(n = 0; n < ARRAY_SIZE(cmds); n++)
+	for(n = 0; n < (int)ARRAY_SIZE(cmds); n++)
 	{
 		if(!strncmp(cmds[n].cmdToken, cmd, cmds[n].tokLen))
 		{
@@ -999,7 +999,7 @@ int execFtpCmd(int sessionId, const char* cmd, int cmdlen)
 
 			if(VERBOSE_MODE_ENABLED) printf("About to execute cmds[n].cmdToken [%s] command [%s] for sessionId = %d\n",cmds[n].cmdToken,&cmd[i],sessionId);
 
-			ret = cmds[n].handler(sessionId, &cmd[i], strlen(&cmd[i]));	// execute command
+			ret = cmds[n].handler(sessionId, &cmd[i], (int)strlen(&cmd[i]));	// execute command
 
 			if(VERBOSE_MODE_ENABLED) printf("Executed cmds[n].cmdToken [%s] command [%s] ret = %d for sessionId = %d\n",cmds[n].cmdToken,&cmd[i],ret,sessionId);
 
