@@ -257,8 +257,9 @@ const char* ftpGetRealPath(int id, const char* path, int normalize)
 	int ftpRootLen;
 	int len;
 
-	strcpy(ftpRoot,ftpGetRoot(sessions[id].userId, &len));
-	ftpRootLen = strlen(ftpRoot);
+	const char *ftp_rootget = ftpGetRoot(sessions[id].userId, &len);
+	snprintf(ftpRoot,2047,"%s",ftp_rootget);
+	ftpRootLen = (int)strlen(ftpRoot);
 	if(ftpRootLen > 0 && ftpRoot[ftpRootLen-1] != '/') {
 		strcat(ftpRoot,"/");
 	}
@@ -313,7 +314,7 @@ if(VERBOSE_MODE_ENABLED) printf("ftpChangeDir path [%s] realPath [%s] sessions[i
 	if(ftpStat(realPath, &fileInfo) || (fileInfo.type != TYPE_DIR)) // directory accessible?
 		return -2;
 
-	strncpy(sessions[id].workingDir, &realPath[len], MAX_PATH_LEN); // apply path
+	strncpy(sessions[id].workingDir, &realPath[len], MAX_PATH_LEN-1); // apply path
 	if(sessions[id].workingDir[0] == '\0')
 		strcpy(sessions[id].workingDir, "/");
 
