@@ -37,7 +37,7 @@ static void init_source(j_decompress_ptr cinfo) {
 }
 static boolean fill_input_buffer (j_decompress_ptr cinfo) {
 	//it is already filled
-	return true;
+	return boolean(true);
 }
 static void skip_input_data (j_decompress_ptr cinfo, long num_bytes) {
 	if (num_bytes > 0) {
@@ -70,7 +70,10 @@ static inline std::vector<string> getExtensions() {
 JPGReader::JPGReader(): FileReader<Pixmap2D>(getExtensions()) {}
 
 Pixmap2D* JPGReader::read(ifstream& is, const string& path, Pixmap2D* ret) const {
-	assert(GlobalStaticFlags::getIsNonGraphicalModeEnabled() == false);
+	if(GlobalStaticFlags::getIsNonGraphicalModeEnabled() == true) {
+		throw megaglest_runtime_error("Loading graphics in headless server mode not allowed!");
+	}
+
 	//Read file
 	is.seekg(0, ios::end);
 	streampos length = is.tellg();
@@ -82,7 +85,10 @@ Pixmap2D* JPGReader::read(ifstream& is, const string& path, Pixmap2D* ret) const
 	is.read((char*)buffer, (std::streamsize)length);
 	static bool bigEndianSystem = Shared::PlatformByteOrder::isBigEndian();
 	if(bigEndianSystem == true) {
-		Shared::PlatformByteOrder::fromEndianTypeArray<uint8>(buffer,length);
+		Shared::PlatformByteOrder::fromEndianTypeArray<uint8>(buffer,(size_t)length);
+	}
+	if(length < 2) {
+		throw megaglest_runtime_error("length < 2",true);
 	}
 	//Check buffer (weak jpeg check)
 	//if (buffer[0] != 0x46 || buffer[1] != 0xA0) {
@@ -147,13 +153,13 @@ Pixmap2D* JPGReader::read(ifstream& is, const string& path, Pixmap2D* ret) const
 	//std::cout << "output width and height: " << cinfo.output_width <<" pixels and " << cinfo.output_height <<" pixels." << std::endl;
 	/* now actually read the jpeg into the raw buffer */
 	row_pointer[0] = new unsigned char[cinfo.output_width*cinfo.num_components];
-	size_t location = 0; //Current pixel
 	/* read one scan line at a time */
 	/* Again you need to invert the lines unfortunately*/
 	while( cinfo.output_scanline < cinfo.output_height )
 	{
 		jpeg_read_scanlines( &cinfo, row_pointer, 1 );
-		location = (cinfo.output_height - cinfo.output_scanline)*cinfo.output_width*picComponents;
+		//Current pixel
+		size_t location = (cinfo.output_height - cinfo.output_scanline) * cinfo.output_width * picComponents;
 		if (picComponents == cinfo.num_components) {
 			memcpy(pixels+location,row_pointer[0],cinfo.output_width*cinfo.num_components);
 		} else {
