@@ -20,6 +20,7 @@
 #include "string_utils.h"
 #include "utf8.h"
 #include "util.h"
+
 #include "leak_dumper.h"
 
 using namespace Shared::Util;
@@ -58,6 +59,7 @@ void TextRenderer2DGl::render(const string &text, float x, float y, bool centere
 	}
 
 	string renderText			= text;
+	Font::bidi_cvt(renderText);
 	int line					= 0;
 	int size					= font->getSize();
 	const unsigned char *utext	= NULL;
@@ -246,7 +248,7 @@ void TextRenderer2DGl::render(const string &text, float x, float y, bool centere
 			}
 
 			glListBase(font->getHandle());
-			glCallLists(renderText.length(), GL_UNSIGNED_SHORT, &utext[0]);
+			glCallLists((GLsizei)renderText.length(), GL_UNSIGNED_SHORT, &utext[0]);
 
 			//std::locale loc("");
 			//wstring wText = widen(text);
@@ -388,6 +390,8 @@ void TextRenderer3DGl::render(const string &text, float  x, float y, bool center
 
 	if(text.empty() == false) {
 		string renderText = text;
+		Font::bidi_cvt(renderText);
+
 		if(Font::fontIsMultibyte == true) {
 			if(font->getTextHandler() != NULL) {
 				if(Font::fontIsRightToLeft == true) {
@@ -573,7 +577,8 @@ void TextRenderer3DGl::internalRender(const string &text, float  x, float y, boo
 			vector<string> parts;
 			char szBuf[8096]="";
 
-			for (int i=0; renderText[i] != '\0'; ++i) {
+			//for (int i=0; renderText[i] != '\0'; ++i) {
+			for(size_t i=0; i < renderText.size(); ++i) {
 				szBuf[0] = '\0';
 				snprintf(szBuf,8096,"%c",renderText[i]);
 
@@ -659,7 +664,7 @@ void TextRenderer3DGl::internalRender(const string &text, float  x, float y, boo
 
 			string utfText = renderText;
 			glListBase(font->getHandle());
-			glCallLists(renderText.length(), GL_UNSIGNED_SHORT, &utext[0]);
+			glCallLists((GLsizei)renderText.length(), GL_UNSIGNED_SHORT, &utext[0]);
 
 			//std::locale loc("");
 			//wstring wText = widen(text);
