@@ -78,7 +78,7 @@ int pot(int x) {
 	return val;
 }
 
-const uint64 MIN_BYTES_TO_COMPRESS = 12;
+const std::size_t MIN_BYTES_TO_COMPRESS = 12;
 
 static std::string getSupportCompressedTextureFormatString(int format) {
 	std::string result = intToStr(format) + "[" + intToHex(format) + "]";
@@ -631,7 +631,7 @@ TextureGl::~TextureGl() {
 // =====================================================
 //	class Texture1DGl
 // =====================================================
-Texture1DGl::Texture1DGl() : TextureGl(), Texture1D() {}
+Texture1DGl::Texture1DGl() : Texture1D(), TextureGl() {}
 
 Texture1DGl::~Texture1DGl() {
 	end();
@@ -753,7 +753,7 @@ void Texture1DGl::end(bool deletePixelBuffer) {
 //	class Texture2DGl
 // =====================================================
 
-Texture2DGl::Texture2DGl() : TextureGl(), Texture2D() {}
+Texture2DGl::Texture2DGl() : Texture2D(), TextureGl() {}
 
 Texture2DGl::~Texture2DGl() {
 	end();
@@ -763,6 +763,7 @@ void Texture2DGl::init(Filter filter, int maxAnisotropy) {
 	assertGl();
 
 	if(inited == false) {
+		assertGl();
 		//params
 		GLint wrap= toWrapModeGl(wrapMode);
 		GLint glFormat= toFormatGl(format, pixmap.getComponents());
@@ -772,6 +773,7 @@ void Texture2DGl::init(Filter filter, int maxAnisotropy) {
 			glCompressionFormat = glInternalFormat;
 		}
 
+		assertGl();
 		//pixel init var
 		const uint8* pixels= pixmapInit? pixmap.getPixels(): NULL;
 
@@ -793,7 +795,7 @@ void Texture2DGl::init(Filter filter, int maxAnisotropy) {
 		}
 
 		if(mipmap) {
-			GLuint glFilter= filter==fTrilinear? GL_LINEAR_MIPMAP_LINEAR: GL_LINEAR_MIPMAP_NEAREST;
+			GLuint glFilter= (filter == fTrilinear ? GL_LINEAR_MIPMAP_LINEAR : GL_LINEAR_MIPMAP_NEAREST);
 
 			//build mipmaps
 			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, glFilter);
@@ -930,7 +932,7 @@ void Texture2DGl::init(Filter filter, int maxAnisotropy) {
 			if(error != GL_NO_ERROR) {
 				const char *errorString= reinterpret_cast<const char*>(gluErrorString(error));
 				char szBuf[8096]="";
-				snprintf(szBuf,8096,"Error creating texture 2D [%s], returned: %d [%s] (%X) [%s] w = %d, h = %d, glInternalFormat = %d, glFormat = %d, glCompressionFormat = %d",this->path.c_str(),error,errorString,error,pixmap.getPath().c_str(),pixmap.getW(),pixmap.getH(),glInternalFormat,glFormat,glCompressionFormat);
+				snprintf(szBuf,8096,"Error creating texture 2D path [%s], returned: %d [%s] (%X) [%s] w = %d, h = %d, glInternalFormat = %d, glFormat = %d, glCompressionFormat = %d",this->path.c_str(),error,errorString,error,pixmap.getPath().c_str(),pixmap.getW(),pixmap.getH(),glInternalFormat,glFormat,glCompressionFormat);
 				throw megaglest_runtime_error(szBuf);
 			}
 		}
@@ -959,7 +961,7 @@ void Texture2DGl::end(bool deletePixelBuffer) {
 //	class Texture3DGl
 // =====================================================
 
-Texture3DGl::Texture3DGl() : TextureGl(), Texture3D() {}
+Texture3DGl::Texture3DGl() : Texture3D(), TextureGl() {}
 
 Texture3DGl::~Texture3DGl() {
 	end();
@@ -1068,7 +1070,7 @@ void Texture3DGl::end(bool deletePixelBuffer) {
 //	class TextureCubeGl
 // =====================================================
 
-TextureCubeGl::TextureCubeGl() : TextureGl(), TextureCube() {}
+TextureCubeGl::TextureCubeGl() : TextureCube(), TextureGl() {}
 
 TextureCubeGl::~TextureCubeGl() {
 	end();
@@ -1261,7 +1263,7 @@ void TextureCubeGl::end(bool deletePixelBuffer) {
 	}
 }
 
-void TextureGl::OutputTextureDebugInfo(Texture::Format format, int components,const string path,uint64 rawSize,GLenum texType) {
+void TextureGl::OutputTextureDebugInfo(Texture::Format format, int components,const string path,std::size_t rawSize,GLenum texType) {
 	if(Texture::useTextureCompression == true) {
 		GLint glFormat= toFormatGl(format, components);
 
