@@ -124,7 +124,9 @@ tm threadsafe_localtime(const time_t &time) {
 // extracting std::time_t from std:chrono for "now"
 time_t systemtime_now() {
 #if __cplusplus > 199711L
-	system_time_point system_now = std::chrono::system_clock::now();
+	// typedef std::chrono::time_point<std::chrono::system_clock>  system_time_point;
+	typedef std::chrono::time_point<std::chrono::system_clock>  system_time_point_x;
+	system_time_point_x system_now = std::chrono::system_clock::now();
 	return std::chrono::system_clock::to_time_t(system_now);
 #else
 	return time(NULL);
@@ -1091,7 +1093,7 @@ uint32 getFolderTreeContentsCheckSumRecursively(const string &path, const string
 	glob_t globbuf;
 
 	int res = glob(mypath.c_str(), 0, 0, &globbuf);
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	if(res < 0) {
 		std::stringstream msg;
 		msg << "#2 Couldn't scan directory '" << mypath << "': " << strerror(errno);
@@ -1125,13 +1127,13 @@ uint32 getFolderTreeContentsCheckSumRecursively(const string &path, const string
 	globfree(&globbuf);
 
     // Look recursively for sub-folders
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 	res = glob(mypath.c_str(), 0, 0, &globbuf);
 #else
 	res = glob(mypath.c_str(), GLOB_ONLYDIR, 0, &globbuf);
 #endif
 
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	if(res < 0) {
 		std::stringstream msg;
 		msg << "#3 Couldn't scan directory '" << mypath << "': " << strerror(errno);
@@ -1140,10 +1142,10 @@ uint32 getFolderTreeContentsCheckSumRecursively(const string &path, const string
 #endif
 
 	for(int i = 0; i < (int)globbuf.gl_pathc; ++i) {
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 		struct stat statStruct;
 		// only process if dir..
-		int actStat = lstat( globbuf.gl_pathv[i], &statStruct);
+		lstat( globbuf.gl_pathv[i], &statStruct);
 		if( S_ISDIR(statStruct.st_mode) == 0)
 			continue;
 #endif
@@ -1272,7 +1274,7 @@ vector<string> getFolderTreeContentsListRecursively(const string &path, const st
 	}
 
 	int res = glob(mypath.c_str(), globFlags, 0, &globbuf);
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	if(res < 0) {
 		std::stringstream msg;
 		msg << "#4 Couldn't scan directory '" << mypath << "': " << strerror(errno);
@@ -1305,14 +1307,14 @@ vector<string> getFolderTreeContentsListRecursively(const string &path, const st
 	globfree(&globbuf);
 
     // Look recursively for sub-folders
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 	res = glob(mypath.c_str(), 0, 0, &globbuf);
 #else //APPLE doesn't have the GLOB_ONLYDIR definition..
 	globFlags |= GLOB_ONLYDIR;
 	res = glob(mypath.c_str(), globFlags, 0, &globbuf);
 #endif
 
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	if(res < 0) {
 		std::stringstream msg;
 		msg << "#5 Couldn't scan directory '" << mypath << "': " << strerror(errno);
@@ -1321,10 +1323,10 @@ vector<string> getFolderTreeContentsListRecursively(const string &path, const st
 #endif
 
 	for(int i = 0; i < (int)globbuf.gl_pathc; ++i) {
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 		struct stat statStruct;
 		// only get if dir..
-		int actStat = lstat( globbuf.gl_pathv[ i], &statStruct);
+		lstat( globbuf.gl_pathv[ i], &statStruct);
 		if( S_ISDIR(statStruct.st_mode) == 0)
 			continue;
 #endif
@@ -1413,7 +1415,7 @@ vector<std::pair<string,uint32> > getFolderTreeContentsCheckSumListRecursively(c
 
 	int res = glob(mypath.c_str(), 0, 0, &globbuf);
 
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	if(res < 0) {
 		std::stringstream msg;
 		msg << "#6 Couldn't scan directory '" << mypath << "': " << strerror(errno);
@@ -1445,13 +1447,13 @@ vector<std::pair<string,uint32> > getFolderTreeContentsCheckSumListRecursively(c
 	globfree(&globbuf);
 
     // Look recursively for sub-folders
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 	res = glob(mypath.c_str(), 0, 0, &globbuf);
 #else //APPLE doesn't have the GLOB_ONLYDIR definition..
 	res = glob(mypath.c_str(), GLOB_ONLYDIR, 0, &globbuf);
 #endif
 
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
+#if !defined(__APPLE__) && !defined(__FreeBSD__) && !defined(__OpenBSD__)
 	if(res < 0) {
 		std::stringstream msg;
 		msg << "#7 Couldn't scan directory '" << mypath << "': " << strerror(errno);
@@ -1460,10 +1462,10 @@ vector<std::pair<string,uint32> > getFolderTreeContentsCheckSumListRecursively(c
 #endif
 
 	for(int i = 0; i < (int)globbuf.gl_pathc; ++i) {
-#if defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__OpenBSD__)
 		struct stat statStruct;
 		// only get if dir..
-		int actStat = lstat( globbuf.gl_pathv[ i], &statStruct);
+		lstat( globbuf.gl_pathv[ i], &statStruct);
 		if( S_ISDIR(statStruct.st_mode) == 0)
 			continue;
 #endif
