@@ -26,6 +26,7 @@ namespace Shared { namespace Platform {
 bool Thread::enableVerboseMode = false;
 Mutex Thread::mutexthreadList;
 vector<Thread *> Thread::threadList;
+unsigned long Thread::mainThreadId = -1;
 
 auto_ptr<Mutex> Mutex::mutexMutexList(new Mutex(CODE_AT_LINE));
 vector<Mutex *> Mutex::mutexList;
@@ -138,6 +139,16 @@ Thread::Thread() : thread(NULL),
 	addThreadToList();
 }
 
+unsigned long Thread::getCurrentThreadId() {
+	return SDL_ThreadID();
+}
+void Thread::setMainThreadId() {
+	mainThreadId = getCurrentThreadId();
+}
+bool Thread::isCurrentThreadMainThread() {
+	return getCurrentThreadId() == mainThreadId;
+}
+
 void Thread::addThreadToList() {
 	MutexSafeWrapper safeMutex(&Thread::mutexthreadList);
 	Thread::threadList.push_back(this);
@@ -145,16 +156,18 @@ void Thread::addThreadToList() {
 }
 void Thread::removeThreadFromList() {
 	MutexSafeWrapper safeMutex(&Thread::mutexthreadList);
-	std::vector<Thread *>::iterator iterFind = std::find(Thread::threadList.begin(),Thread::threadList.end(),this);
-	if(iterFind == Thread::threadList.end()) {
-		if(this != cleanupThread.get()) {
-			char szBuf[8096]="";
-			snprintf(szBuf,8095,"In [%s::%s Line: %d] iterFind == Thread::threadList.end()",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__);
-			throw megaglest_runtime_error(szBuf);
+	if(Thread::threadList.empty() == false) {
+		std::vector<Thread *>::iterator iterFind = std::find(Thread::threadList.begin(),Thread::threadList.end(),this);
+		if(iterFind == Thread::threadList.end()) {
+			if(this != cleanupThread.get()) {
+				char szBuf[8096]="";
+				snprintf(szBuf,8095,"In [%s::%s Line: %d] iterFind == Thread::threadList.end() Thread::threadList.size() = %ld",extractFileFromDirectoryPath(__FILE__).c_str(),__FUNCTION__,__LINE__,Thread::threadList.size());
+				throw megaglest_runtime_error(szBuf);
+			}
+		}
+		else {
+			Thread::threadList.erase(iterFind);
 		}
-	}
-	else {
-		Thread::threadList.erase(iterFind);
 	}
 	safeMutex.ReleaseLock();
 }
