@@ -266,7 +266,7 @@ int glob(   char const  *pattern
 
             //cch = lstrlenW(find_data.cFileName);
 			string sFileName = utf8_encode(find_data.cFileName);
-			cch = sFileName.length();
+			cch = (int)sFileName.length();
             if(NULL != file_part)
             {
                 cch += (int)(file_part - effectivePattern);
@@ -297,6 +297,9 @@ int glob(   char const  *pattern
                 cbAlloc = new_cbAlloc;
             }
 
+			if(buffer == NULL) {
+				throw exception("buffer == NULL");
+			}
             (void)lstrcpynA(buffer + cbCurr, szRelative, 1 + (int)(file_part - effectivePattern));
             (void)lstrcatA(buffer + cbCurr, sFileName.c_str());
             cbCurr += cch + 1;
