@@ -3,9 +3,10 @@
 # script to create HTML-pages and diagrams from the glest-factions techtree
 # 20110120, bugs & feedback to olaus@rupp.de
 # Copyright 2011 olaus
+# Copyright 2012-2016 olaus & MegaGlest Team
 # license: GPLv3 or newer
 
-our $version = "0.8 beta";
+our $version = "0.8.1 beta";
 
 # This tool requires jquery and the jquery dataTables plugin (run setupDeps.sh which uses curl to try to download these into the media folder). 
 # These are NOT required to run the script but are used to display the resulting html.
@@ -81,7 +82,6 @@ our $version = "0.8 beta";
 
 # strange stuff in the techtrees:
 # - persian magician splash radius 0?
-# - tech workers move faster with load?
 # - tech upgrades piercing/blade weapon don't work for battle machine?
 # - f.e. battle machine with "hold" will only attack land units
 # - workers are able to help a technician build an aerodrome faster. is that wanted?
@@ -909,7 +909,7 @@ foreach my $faction_path ( @factions ) {
 
 
 		# show levels
-		if ( defined @{ $u_levels{ $u }} ) {
+		if ( $u_levels{ $u } ) {
 
 			my $level_num = 0;
 
@@ -943,7 +943,7 @@ foreach my $faction_path ( @factions ) {
 		}
 
 		# show available upgrades for this unit
-		if ( defined @{ $upgrades_for{ $u }} ) {
+		if ( $upgrades_for{ $u } ) {
 
 			$full_attack_tmp .= "<TR><TD>Upgrades Available:</TD><TD>";
 
@@ -1157,13 +1157,13 @@ foreach my $faction_path ( @factions ) {
 			$found = 0;
 
 			if ( $relation =~ /Require/i ) {
-				$full_tmp = "<TR><TD>$unit_pretty is a $relation for:</TD><TD>";
+				$full_tmp = "<TR><TD>'$unit_pretty' is a $relation for:</TD><TD>";
 			}
 			elsif ( $relation =~ /Command/i ) {
-				$full_tmp = "<TR><TD>$unit_pretty enables commands:</TD><TD>";
+				$full_tmp = "<TR><TD>'$unit_pretty' enables commands:</TD><TD>";
 			}
 			else {
-				$full_tmp = "<TR><TD>$unit_pretty is able to $relation:</TD><TD>";
+				$full_tmp = "<TR><TD>'$unit_pretty' is able to $relation:</TD><TD>";
 			}
 	
 			my $last_command="";
@@ -1175,7 +1175,7 @@ foreach my $faction_path ( @factions ) {
 				if ( $command ) {
 					$full_tmp .= &format_name($command)." : ".&link_unit($faction, $req_unit)."<br>\n";
 					if ( $command ne $last_command ) {
-						$req_overview_tmp .= "Enables command <i>".&format_name($command)."</i> for: ";
+						$req_overview_tmp .= "Enables command '<i>".&format_name($command)."</i>' for: ";
 					}
 					$req_overview_tmp .= &link_unit($faction, $req_unit).", ";
 					$last_command=$command;
@@ -1191,20 +1191,25 @@ foreach my $faction_path ( @factions ) {
 			if ( $found ) {
 				print "found enables for $u\n";
 				$full .= $full_tmp;
-				chop $req_overview_tmp;
-				chop $req_overview_tmp;
-				$req_overview_tmp = "<TD>$req_overview_tmp";
+				# detect unit & command in one cell
+				my $found_unit_command = grep /<A HREF=.*Enables command/, $req_overview_tmp;
+				if ( !$found_unit_command ) {
+					$req_overview_tmp = "<TD>$req_overview_tmp";
+				}
 			}
 
 		}
-
+		if ( defined $req_overview_tmp && length $req_overview_tmp ) {
+			chop $req_overview_tmp;
+			chop $req_overview_tmp;
+		}
 		$req_overview_tmp = $req_overview_tmp || "<TD>&nbsp;";
 
 
 
 		# print what's needed to build this unit and what is enabled to built by this unit
 		$found = 0;
-		$full_tmp = "<TR><TD>Needed to build $unit_pretty:</TD><TD>";
+		$full_tmp = "<TR><TD>Needed to build '$unit_pretty':</TD><TD>";
 		foreach my $unit_requirement ( @{$c_unit_requires{"$faction:$unit"}} ) {
 			my ( $faction, $req_unit ) = split(/:/, $unit_requirement );
 			my $req_unit_pretty = &format_name( $req_unit );
@@ -1921,18 +1926,20 @@ sub get_value {
 	my $nodeset = $xpath->find("$location");
 	print "doing location $location\n";
 	my ($node) = $nodeset->get_nodelist;
-
 	my $value;
 	if ( $node ) {
 		my $attribute = XML::XPath::XMLParser::as_string( $node );
-
 		# get only the value of an attribute, XML::Xpath returns f.e. regeneration="3", we want just 3
-		if ( $attribute =~ /\"(.+?)\"/ ) {
+		if ( $attribute =~ /(?<!value-percent-multiplier)[ \t]*=[ \t]*\"[ \t]*(.+?)[ \t]*\"/ ) {
 			$value = $1;
+
+			if ( $attribute =~ /value-percent-multiplier[ \t]*=[ \t]*\"[ \t]*true[ \t]*\"/ ) {
+				$value = "$value%";
+			}
 		}
-		else {
-			$value = $attribute;
-		}
+		#else {
+		#	$value = $attribute;
+		#}
 	}
 	return $value;
 
@@ -2360,7 +2367,7 @@ sub show_attack {
 	my $target;
 
 
-	my $full_attack_tmp = "<TR><TD>Attack Command: $command_pretty".&html_icon_command( $c, 32 )."</TD><TD>\n";
+	my $full_attack_tmp = "<TR><TD>Attack Command: $command_pretty<BR>".&html_icon_command( $c, 32 )."</TD><TD>\n";
 
 	my $skill = $attack_skill{ $c };
 	# attacks have own move_skills (charge)
